==> openshift-model-whereabouts-6.7.1-sources.jar: io/fabric8/openshift/api/model/whereabouts/v1alpha1/IPPoolListBuilder.java <==
package io.fabric8.openshift.api.model.whereabouts.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IPPoolListBuilder extends IPPoolListFluentImpl<IPPoolListBuilder> implements VisitableBuilder<IPPoolList,IPPoolListBuilder>{
  public IPPoolListBuilder() {
    this(false);
  }
  public IPPoolListBuilder(Boolean validationEnabled) {
    this(new IPPoolList(), validationEnabled);
  }
  public IPPoolListBuilder(IPPoolListFluent<?> fluent) {
    this(fluent, false);
  }
  public IPPoolListBuilder(IPPoolListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IPPoolList(), validationEnabled);
  }
  public IPPoolListBuilder(IPPoolListFluent<?> fluent,IPPoolList instance) {
    this(fluent, instance, false);
  }
  public IPPoolListBuilder(IPPoolListFluent<?> fluent,IPPoolList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IPPoolListBuilder(IPPoolList instance) {
    this(instance,false);
  }
  public IPPoolListBuilder(IPPoolList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  IPPoolListFluent<?> fluent;
  Boolean validationEnabled;
  public IPPoolList build() {
    IPPoolList buildable = new IPPoolList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-whereabouts-6.8.1-sources.jar: io/fabric8/openshift/api/model/whereabouts/v1alpha1/IPPoolListBuilder.java <==
package io.fabric8.openshift.api.model.whereabouts.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IPPoolListBuilder extends IPPoolListFluent<IPPoolListBuilder> implements VisitableBuilder<IPPoolList,IPPoolListBuilder>{
  public IPPoolListBuilder() {
    this(false);
  }
  public IPPoolListBuilder(Boolean validationEnabled) {
    this(new IPPoolList(), validationEnabled);
  }
  public IPPoolListBuilder(IPPoolListFluent<?> fluent) {
    this(fluent, false);
  }
  public IPPoolListBuilder(IPPoolListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IPPoolList(), validationEnabled);
  }
  public IPPoolListBuilder(IPPoolListFluent<?> fluent,IPPoolList instance) {
    this(fluent, instance, false);
  }
  public IPPoolListBuilder(IPPoolListFluent<?> fluent,IPPoolList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new IPPoolList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IPPoolListBuilder(IPPoolList instance) {
    this(instance,false);
  }
  public IPPoolListBuilder(IPPoolList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new IPPoolList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  IPPoolListFluent<?> fluent;
  Boolean validationEnabled;
  public IPPoolList build() {
    IPPoolList buildable = new IPPoolList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
